@@ -7,7 +7,7 @@ use Spellunker::Pod;
 
 use parent qw(Exporter);
 
-use version; our $VERSION = version->declare("v0.2.1");
+use version; our $VERSION = version->declare("v0.2.2");
 
 use Test::Builder;
 use File::Spec;
@@ -18,6 +18,7 @@ our @EXPORT = qw(
   pod_file_spelling_ok
   all_pod_files_spelling_ok
   add_stopwords
+  load_dictionary
 );
 
 my $TEST = Test::Builder->new();
@@ -112,9 +113,14 @@ sub pod_file_spelling_ok {
 }
 
 sub add_stopwords {
-    $SPELLUNKER->add_stopwords(@_)
+    $SPELLUNKER->add_stopwords(@_);
 }
 
+sub load_dictionary {
+    $SPELLUNKER->load_dictionary(@_);
+}
+
+
 1;
 __END__
 
@@ -193,6 +199,10 @@ Pod::Spell already skips words believed to be code, such as everything
 in verbatim (indented) blocks and code marked up with ""..."", as well
 as some common Perl jargon.
 
+=item load_dictionary($filename_or_fh)
+
+Load stopwords from C<$filename_or_fh>. You may want to use it as C<< load_dictionary(\*DATA) >>.
+
 =back
 
 =head1 HOW DO I ADD FILE SPECIFIC STOPWORDS?
